@@ -1,9 +1,7 @@
 package Spoon::Plugin;
-use strict;
-use warnings;
-use Spoon::Base '-Base';
+use Spoon::Base -Base;
 
-const plugin_base_directory => './plugin';
+sub class_title_prefix { () }
 
 sub class_id {
     my $package = ref $self;
@@ -11,23 +9,19 @@ sub class_id {
     lc($package);
 }
 
+sub class_title {
+    join ' ', map {
+        s/(.*)/\u$1/;
+        $_;
+    } $self->class_title_prefix, split '_', $self->class_id;
+}
+
 sub register {
     $self->hub->registry->add(action => $self->class_id, 'process')
       if $self->can('process');
     return $self;
 }
 
-sub plugin_directory {
-    my $dir = join '/',
-        $self->plugin_base_directory,
-        $self->class_id,
-    ;
-    mkdir $dir unless -d $dir;
-    return $dir;
-}
-    
-1;
-
 __END__
 
 =head1 NAME 
