@@ -1,19 +1,16 @@
 package Spoon::Template;
-use strict;
-use warnings;
-use Spoon '-Base';
+use Spoon::Base -Base;
 use Template;
 
 const class_id => 'template';
-const default_path => [ './template' ];
+const template_path => [ './template' ];
 field path => [];
 stub 'render';
+field config => -init => '$self->hub->config';
+field cgi => -init => '$self->hub->cgi';
 
 sub init {
-    $self->use_class('config');
-    $self->use_class('cgi')
-      if $self->is_in_cgi;
-    $self->add_path(@{$self->default_path});
+    $self->add_path(@{$self->template_path});
 }
 
 sub all {
@@ -25,7 +22,17 @@ sub all {
 }
 
 sub add_path {
-    splice @{$self->path}, 0, 0, @_;
+    for (reverse @_) {
+        $self->remove_path($_);
+        unshift @{$self->path}, $_;
+    }
+}
+
+sub append_path {
+    for (@_) {
+        $self->remove_path($_);
+        push @{$self->path}, $_;
+    }
 }
 
 sub remove_path {
@@ -35,28 +42,14 @@ sub remove_path {
 
 sub process {
     my $template = shift;
-    my %vars = @_;
-    my $directives = {};
-    for my $key (keys %vars) {
-        if ($key =~ /^-([A-Z_]+)$/) {
-            $directives->{$1} = $vars{$key};
-            delete $vars{$key};
-        }
-    }
-    my @vars = (
-        $self->all,
-        %vars,
-    );
     my @templates = (ref $template eq 'ARRAY')
       ? @$template 
       : $template;
     return join '', map {
-        $self->render($_, $directives, @vars)
+        $self->render($_, $self->all, @_)
     } @templates;
 }
 
-1;
-
 __END__
 
 =head1 NAME 
