@@ -1,7 +1,5 @@
 package Spoon::Utils;
-use strict;
-use warnings;
-use Spiffy '-Base';
+use Spiffy -Base;
 const directory_perms => 0755;
 
 sub assert_filepath {
@@ -25,8 +23,6 @@ sub remove_tree {
     File::Path::rmtree($directory);
 }
 
-1;
-
 __END__
 
 =head1 NAME 
